<?php
/**
 * Claremont output functions.
 */

/**
 * Display Site Branding.
 */
if ( ! function_exists( 'claremont_site_branding' ) ) {
	function claremont_site_branding( $output = '' ) {

		$output .= '<div class="container"><div class="site-branding"><div class="top-logo">';

		if ( get_theme_mod('custom_logo') ) {
			$output .= get_custom_logo();
		} else {
			if ( is_front_page() ) {
				$output .='<h1 class="site-title"><a href="'.esc_url( home_url('/') ).'" rel="home">'.get_bloginfo('name').'</a></h1>';
			} else {
				$output .='<p class="site-title"><a href="'.esc_url( home_url('/') ).'" rel="home">'.get_bloginfo('name').'</a></p>';
			}
		}

		$output .= '</div>';


		$claremont_top_btn = get_theme_mod( 'claremont_top_btn' );
			if ( '' != get_theme_mod( 'claremont_top_btn' ) ) {
				$site_description_append = '';
				$output .= '<div class="top-cta"><a href="'.get_page_link($claremont_top_btn).'" class="btn">'.get_the_title($claremont_top_btn).'</a></div>';
			} else {
				$site_description_append = '-76';
			}

		$output .= '<div class="top-right'.$site_description_append.'">';

		$claremont_subtitle = get_bloginfo( 'description' );
			if ( '' != get_bloginfo( 'description' ) ) {
				$output .= '<p class="site-description">'.esc_html( $claremont_subtitle ).'</p>';
			}

		$claremont_tel_text = get_theme_mod( 'claremont_tel_text' );
			if ( '' != get_theme_mod( 'claremont_tel_text' ) ) {
				$output .= '<p class="top-leadin">'.esc_html( $claremont_tel_text ).'</p>';
			}

		$claremont_tel_num = get_theme_mod( 'claremont_tel_num' );
			if ( '' != get_theme_mod( 'claremont_tel_num' ) ) {
				$output .= '<p class="top-tel">'.esc_html( $claremont_tel_num ).'</p>';
			}

		$output .= '</div></div></div>';

		echo $output;
	}
}

/**
 * Display Main Menu.
 */
if ( ! function_exists( 'claremont_site_navigation' ) ) {
	function claremont_site_navigation( $output = '' ) {
		$output .= '<div class="nav-container">';
		$output .= '<div class="site-navigation" role="navigation">';
			$output .= '<div class="container">';
				$output .= '<a class="mobile-trigger" href="javascript:void(0);"><span></span></a>';
				$output .= wp_nav_menu(
					array(
						'theme_location' => 'primary',
						'menu_id'        => 'primary-menu',
						'menu_class'     => 'clear',
						'container'      => false,
						'echo'           => false,
						'fallback_cb'    => '',
					)
				);
				
			$search_icon = get_theme_mod('search_icon', 1);
			if ($search_icon) {
				$output .= '<div class="site-search">';
					$output .= '<a class="claremont-search" href="#search" role="button"><i class="fa fa-search"></i></a>';
				$output .= '</div>';
			}

			$output .= '</div>';
		$output .= '</div>';
		$output .= '</div>';

		echo $output;
	}
}

/**
 * Display Widgets Above Content.
 */
if ( ! function_exists( 'claremont_home_widgets' ) ) {
	function claremont_home_widgets() {
		echo '<div class="container">';
			echo '<div class="home-widget-left">';
					dynamic_sidebar( 'home-top-left' );
			echo '</div>';
			echo '<div class="home-widget-right">';
					dynamic_sidebar( 'home-top-right' );
			echo '</div>';
		echo '</div>';
	}
}

/**
 * Display Widgets Above Footer.
 */
if ( ! function_exists( 'claremont_footer_above_widget_area' ) ) {
	function claremont_footer_above_widget_area() {
		echo '<div class="container">';
			echo '<div class="home-footer-above">';
					dynamic_sidebar( 'home-footer-above' );
			echo '</div>';
		echo '</div>';
	}
}

/**
 * Prints title of blog post.
 */
if ( ! function_exists( 'claremont_post_title' ) ) {
	function claremont_post_title() {
		the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
	}
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'claremont_posted_on' ) ) {
	function claremont_posted_on() {
		$show_date = get_theme_mod('show_date', 1);
		if ($show_date) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() )
			);

			$posted_on = sprintf(
				esc_html_x( '%s', 'post date', 'claremont' ),
				'<i class="fa-calendar"></i><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);

			echo '<span class="posted-on">' . $posted_on . '</span>';
		}
	}
}

/**
 * Prints HTML author post.
 */
if ( ! function_exists( 'claremont_post_author' ) ) {
	function claremont_post_author() {
		$show_author = get_theme_mod('show_author', 1);
		if ($show_author) {
			$byline = sprintf(
				esc_html_x( '%s', 'post author', 'claremont' ),
				'<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
			);

		echo '<span class="byline author vcard"><i class="fa-user"></i>' . esc_html__( 'By ', 'claremont' ) . $byline . '</span>';
		}
	}
}

/**
 * Prints HTML with meta information for the comments.
 */
if ( ! function_exists( 'claremont_post_comments' ) ) {
	function claremont_post_comments() {
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link"><i class="fa-comment"></i>';
			comments_popup_link( esc_html__( 'Leave a comment', 'claremont' ), esc_html__( '1 Comment', 'claremont' ), esc_html__( '% Comments', 'claremont' ) );
			echo '</span>';
		}
	}
}

/**
 * Prints HTML with meta information for the categories.
 */
if ( ! function_exists( 'claremont_post_cats' ) ) {
	function claremont_post_cats() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'claremont' ) );
			if ( $categories_list && claremont_categorized_blog() ) {
				printf( '<span class="cat-links"><i class="fa-folder"></i>' . esc_html__( '%1$s', 'claremont' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}
		}
	}
}

/**
 * Prints HTML with meta information for the tags.
 */
if ( ! function_exists( 'claremont_post_tags' ) ) {
	function claremont_post_tags() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'claremont' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links"><i class="fa-tag"></i>' . esc_html__( '%1$s', 'claremont' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}
	}
}

/**
 * Prints HTML with meta information for the tags.
 */
if ( ! function_exists( 'claremont_post_read_more' ) ) {
	function claremont_post_read_more() {
		global $post;
		if ( strpos( $post->post_content , "<!--more-->" ) != false ) :
			echo '<a class="more-link" href="' . esc_url( get_permalink() ) . '">' . esc_html__( 'Read more', 'claremont' ) . '</a>';
		endif;
	}
}

/**
 * Display the post thumbnail, follow post format.
 */
if ( ! function_exists( 'claremont_post_thumbnail' ) ) {
	function claremont_post_thumbnail() {
		global $post;
		// Get post format
		$post_format = get_post_format();

		switch ( $post_format ):
			case 'gallery' :
				// Get image id
				$images = get_post_meta( get_the_ID(), 'claremont_gallery', false );
				$photos = array();

				foreach ( $images as $id ) {
					$link     = wp_get_attachment_image_src( $id, $size );
					$photos[] = $link[0];
				}

				if ( ! empty( $photos ) ) {
					echo '<div class="claremont-gallery">';
						foreach ( $photos as $photo ) {
							$data = getimagesize( $photo );
							echo '<img src="' . esc_url( $photo ) . '" width="' . esc_attr( $data[0] ) . '" height="' . esc_attr( $data[1] ) . '" />';
						}
					echo '</div>';
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'audio' :
				$audio      = get_post_meta( $post->ID, 'claremont_audio_source', true );
				$soundcloud = get_post_meta( $post->ID, 'claremont_audio_link', true );
				$localfile  = get_post_meta( $post->ID, 'claremont_audio_self_hosted', true );
				if ( 'soundcloud' == $audio ) {
					global $wp_embed;
					$media_result = $wp_embed->run_shortcode( '[embed]' . esc_url( $soundcloud ) . '[/embed]' );
					echo $media_result;
				} elseif ( 'local' == $audio ) {
					echo do_shortcode('[audio src="' . esc_url( $localfile ) . '"/]');
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'video' :
				$video       = get_post_meta( $post->ID, 'claremont_video_source', true );
				$video_url   = get_post_meta( $post->ID, 'claremont_video_link', true );
				$video_embed = get_post_meta( $post->ID, 'claremont_video_embed', true );
				$video_local = get_post_meta( $post->ID, 'claremont_video_self_hosted', true );

				if ( 'link' == $video ) {
					global $wp_embed;
					$media_result = $wp_embed->run_shortcode( '[embed]' . esc_url( $video_url ) . '[/embed]' );
					echo $media_result;
				} elseif ( 'embed' == $video ) {
					echo $video_embed;
				} elseif ( 'local' == $video ) {
					echo do_shortcode('[video src="' . esc_url( $video_local ) . '"/]');
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'quote' :
			default :
				if ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;
		endswitch;
	}
}

/**
 * Trim content.
 */
function claremont_custom_excerpt_length( $length ) {
	$trim_content_words = get_theme_mod('trim_content_words');
	if ($trim_content_words && $trim_content_words > 0) {
		return $trim_content_words;
	} else {
		return 70;
	}
}

/**
 * Custom excerpt 'continue reading' link.
 */
function claremont_custom_excerpt_more( $more ) {
    return '&hellip; <a href="'.get_the_permalink().'" rel="nofollow">' . esc_html__( 'continue reading', 'claremont' ) . '</a>';
}

if ( ! is_admin() ) {
	add_filter( 'excerpt_length', 'claremont_custom_excerpt_length', 999 );
	add_filter( 'excerpt_more', 'claremont_custom_excerpt_more' );
}

/**
 * Post author avatar/bio.
 */
if ( ! function_exists( 'claremont_get_author' ) ) {
	function claremont_get_author() {
 		$show_author = get_theme_mod('show_author', 1);
 		if ($show_author) {
			$author = sprintf(
				'<div class="post-author">' . __( '%1$s%2$s', 'claremont' ) . '</div>',
				get_avatar( get_the_author_meta( 'user_email' ), '60', '' ),
				'<div class="author-info"><a class="name" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a><p>' . get_the_author_meta( 'description' ) . '</p></div>'

				);
			echo $author;
		}
 	}
}

/**
 * Returns true if a blog has more than 1 category.
 */
function claremont_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'claremont_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'claremont_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so claremont_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so claremont_categorized_blog should return false.
		return false;
	}
}

/**
 * Display Site Info.
 */
if ( ! function_exists( 'claremont_site_info' ) ) {
	function claremont_site_info( $output = '' ) {
		$copyright = get_theme_mod( 'footer_content' );
		?>
		<div class="site-info">
			<?php
			if ( ! empty( $copyright ) ) {
				echo wp_kses_post( $copyright );
			} else {
				printf( esc_html__( '&copy; %1$s %2$s - All Rights Reserved.', 'claremont' ), get_the_time( 'Y' ), get_bloginfo() );
			}
			?>
		</div>
		<div class="theme-info">
			<?php if ( function_exists( 'the_privacy_policy_link' ) && !claremont_privacy_in_menu() ) {
				the_privacy_policy_link( '', '<span class="sep privacy"> | </span>' );
			} ?>
			<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'claremont' ) ); ?>"><?php printf( esc_html__( 'Powered by %s', 'claremont' ), 'WordPress' ); ?></a>
			<span class="sep"> | </span>
			<?php printf( esc_html__( 'Theme: %2$s by %1$s', 'claremont' ), 'uXL Themes', '<a href="https://uxlthemes.com/theme/claremont/" rel="designer">Claremont</a>' ); ?>
		</div>
		<?php
	}
}



/**
 * Check if Privacy Policy page is already in theme primary or footer menu
 */
if( ! function_exists( 'claremont_privacy_in_menu' ) ) {
	function claremont_privacy_in_menu(){

		$menu_page_ids = array();

		$locations = get_nav_menu_locations();

		if ( has_nav_menu( 'primary' ) ) {
			$menu_name_primary = wp_get_nav_menu_object( $locations[ 'primary' ] );
			$menu_items_primary = wp_get_nav_menu_items( $menu_name_primary );
			foreach ( $menu_items_primary as $menu_item_primary ) {
				if ( $menu_item_primary->object == 'page' ) {
					$menu_page_ids[] = $menu_item_primary->object_id;
				}
			}
		}

		$privacy_policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
		if ( ! empty( $privacy_policy_page_id ) && get_post_status( $privacy_policy_page_id ) === 'publish' && in_array( $privacy_policy_page_id, $menu_page_ids ) ) {
			return true;
		} else {
			return false;
		}

	}
}

/**
 * Footer widget areas.
 */
if ( ! function_exists( 'claremont_footer_widget_area' ) ) {
	function claremont_footer_widget_area() {
		// Count the number of footer sidebars	
		$count = 0;

		if ( is_active_sidebar( 'footer-1' ) )
			$count++;

		if ( is_active_sidebar( 'footer-2' ) )
			$count++;

		if ( is_active_sidebar( 'footer-3' ) )
			$count++;

		if ( is_active_sidebar( 'footer-4' ) )
			$count++;

		$i = 1; $i <= 4; $i++;

		// Render footer widget sidebar
		echo '<div class="footer-widget">';
			switch ( $count ) {
				case '1' :
					for ( $i = 1; $i <= 1; $i++ ) {
						echo '<div class="col-1">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '2' :
					for ( $i = 1; $i <= 2; $i++ ) {
						echo '<div class="col-2">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '3' :
					for ( $i = 1; $i <= 3; $i++ ) {
						echo '<div class="col-3">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '4' :
					for ( $i = 1; $i <= 4; $i++ ) {
						echo '<div class="col-4">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
			}
		echo '</div>';
	}
}